==> aws-cdk-scala-alexa_3-0.4.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"alexa","t":"alexa","d":"","k":"static"},
{"l":"io/burkard/cdk/alexa.html","n":"io.burkard.cdk.alexa","t":"package io.burkard.cdk.alexa","d":"io/burkard/cdk/alexa","k":"package"},
{"l":"io/burkard/cdk/alexa/AuthenticationConfigurationProperty$.html","n":"AuthenticationConfigurationProperty","t":"object AuthenticationConfigurationProperty","d":"io/burkard/cdk/alexa/AuthenticationConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/alexa/AuthenticationConfigurationProperty$.html","n":"apply","t":"def apply(refreshToken: String, clientSecret: String, clientId: String): AuthenticationConfigurationProperty","d":"io/burkard/cdk/alexa/AuthenticationConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/alexa/CfnSkill$.html","n":"CfnSkill","t":"object CfnSkill","d":"io/burkard/cdk/alexa/CfnSkill$","k":"object"},
{"l":"io/burkard/cdk/alexa/CfnSkill$.html","n":"apply","t":"def apply(internalResourceId: String, authenticationConfiguration: AuthenticationConfigurationProperty, skillPackage: SkillPackageProperty, vendorId: String)(implicit stackCtx: Stack): CfnSkill","d":"io/burkard/cdk/alexa/CfnSkill$","k":"def"},
{"l":"io/burkard/cdk/alexa/CfnSkillProps$.html","n":"CfnSkillProps","t":"object CfnSkillProps","d":"io/burkard/cdk/alexa/CfnSkillProps$","k":"object"},
{"l":"io/burkard/cdk/alexa/CfnSkillProps$.html","n":"apply","t":"def apply(authenticationConfiguration: AuthenticationConfigurationProperty, skillPackage: SkillPackageProperty, vendorId: String): CfnSkillProps","d":"io/burkard/cdk/alexa/CfnSkillProps$","k":"def"},
{"l":"io/burkard/cdk/alexa/OverridesProperty$.html","n":"OverridesProperty","t":"object OverridesProperty","d":"io/burkard/cdk/alexa/OverridesProperty$","k":"object"},
{"l":"io/burkard/cdk/alexa/OverridesProperty$.html","n":"apply","t":"def apply(manifest: Option[AnyRef]): OverridesProperty","d":"io/burkard/cdk/alexa/OverridesProperty$","k":"def"},
{"l":"io/burkard/cdk/alexa/SkillPackageProperty$.html","n":"SkillPackageProperty","t":"object SkillPackageProperty","d":"io/burkard/cdk/alexa/SkillPackageProperty$","k":"object"},
{"l":"io/burkard/cdk/alexa/SkillPackageProperty$.html","n":"apply","t":"def apply(s3Bucket: String, s3Key: String, overrides: Option[OverridesProperty], s3BucketRole: Option[String], s3ObjectVersion: Option[String]): SkillPackageProperty","d":"io/burkard/cdk/alexa/SkillPackageProperty$","k":"def"},
{"l":"docs/index.html","n":"alexa","t":"alexa","d":"","k":"static"}];

==> aws-cdk-scala-alexa_3-0.4.1-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"alexa","t":"alexa","d":"","k":"static"},
{"l":"io/burkard/cdk/alexa.html","n":"io.burkard.cdk.alexa","t":"package io.burkard.cdk.alexa","d":"io/burkard/cdk/alexa","k":"package"},
{"l":"io/burkard/cdk/alexa/AuthenticationConfigurationProperty$.html","n":"AuthenticationConfigurationProperty","t":"object AuthenticationConfigurationProperty","d":"io/burkard/cdk/alexa/AuthenticationConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/alexa/AuthenticationConfigurationProperty$.html","n":"apply","t":"def apply(clientId: String, clientSecret: String, refreshToken: String): AuthenticationConfigurationProperty","d":"io/burkard/cdk/alexa/AuthenticationConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/alexa/CfnSkill$.html","n":"CfnSkill","t":"object CfnSkill","d":"io/burkard/cdk/alexa/CfnSkill$","k":"object"},
{"l":"io/burkard/cdk/alexa/CfnSkill$.html","n":"apply","t":"def apply(internalResourceId: String, authenticationConfiguration: AuthenticationConfigurationProperty, skillPackage: SkillPackageProperty, vendorId: String)(implicit stackCtx: Stack): CfnSkill","d":"io/burkard/cdk/alexa/CfnSkill$","k":"def"},
{"l":"io/burkard/cdk/alexa/CfnSkillProps$.html","n":"CfnSkillProps","t":"object CfnSkillProps","d":"io/burkard/cdk/alexa/CfnSkillProps$","k":"object"},
{"l":"io/burkard/cdk/alexa/CfnSkillProps$.html","n":"apply","t":"def apply(authenticationConfiguration: AuthenticationConfigurationProperty, skillPackage: SkillPackageProperty, vendorId: String): CfnSkillProps","d":"io/burkard/cdk/alexa/CfnSkillProps$","k":"def"},
{"l":"io/burkard/cdk/alexa/OverridesProperty$.html","n":"OverridesProperty","t":"object OverridesProperty","d":"io/burkard/cdk/alexa/OverridesProperty$","k":"object"},
{"l":"io/burkard/cdk/alexa/OverridesProperty$.html","n":"apply","t":"def apply(manifest: Option[AnyRef]): OverridesProperty","d":"io/burkard/cdk/alexa/OverridesProperty$","k":"def"},
{"l":"io/burkard/cdk/alexa/SkillPackageProperty$.html","n":"SkillPackageProperty","t":"object SkillPackageProperty","d":"io/burkard/cdk/alexa/SkillPackageProperty$","k":"object"},
{"l":"io/burkard/cdk/alexa/SkillPackageProperty$.html","n":"apply","t":"def apply(s3Bucket: String, s3Key: String, overrides: Option[OverridesProperty], s3BucketRole: Option[String], s3ObjectVersion: Option[String]): SkillPackageProperty","d":"io/burkard/cdk/alexa/SkillPackageProperty$","k":"def"},
{"l":"docs/index.html","n":"alexa","t":"alexa","d":"","k":"static"}];
